# -*- coding: utf-8 -*-
from rembg import remove
import matplotlib.pyplot as plt  # 数据可视化
import jieba  # 词语切割
import wordcloud  # 分词
from wordcloud import WordCloud, ImageColorGenerator, STOPWORDS  # 词云，颜色生成器，停止词
import numpy as np  # 科学计算
from PIL import Image # 处理图片
import collections  # 词频统计库
import re
import codecs
from textrank4zh import TextRank4Keyword, TextRank4Sentence


class WordCloudCreator(object):
    """
    根据图片和文字创建词云
    """
    def __init__(self, file_path, pic_path, pic_process=True, text_process=True):
        """
        Initialization.
        """
        self.file_path = file_path
        self.pic_path = pic_path
        self.pic_process = pic_process
        self.text_process = text_process

    def run(self):
        """
        Create word cloud result.
        """
        if self.pic_process:
            # 第一步：读取图片并去除背景
            input = Image.open(self.pic_path)
            output = remove(input)
            output_path = 'output_rm.png'
            output.save(output_path)

            # 第二步：将去除背景的图片背景转换为白色（为了词云图背景设置）
            img = Image.open(output_path).convert('RGBA')
            W, L = img.size
            white_pixel = (255, 255, 255, 255)  # 白色
            for h in range(W):
                for i in range(L):
                    if img.getpixel((h, i)) in [(0, 0, 0, 0)]:
                        img.putpixel((h, i), white_pixel)  # 设置透明
            img.save(output_path)  # 自己设置保存地址
            self.pic_path = output_path

        # 第三步：对文章内容进行处理，并提取关键词计算词频/词权重
        stopwords = [i.strip() for i in open('cn_stopwords.txt').readlines()]
        stopwords.extend(['没有', '一个', '现在', '像是'])
        if self.text_process:
            text = codecs.open('clj.txt', 'r', 'utf-8').read()
            tr4w = TextRank4Keyword()
            tr4w.analyze(text=text, lower=True, window=2)
            frequency_dic = {}
            for item in tr4w.get_keywords(1000, word_min_len=2):
                if item.word in stopwords:
                    continue
                frequency_dic[item.word] = item.weight
            word_counts = frequency_dic
        else:
            with open(self.file_path, 'r', encoding='utf8') as f:  # 打开新的文本转码为gbk
                textfile = f.read()  # 读取文本内容
            # 文本预处理
            pattern = re.compile(u'\t|\n|\.|-|:|;|\)|\(|\?|"')  # 定义正则表达式匹配模式
            textfile = re.sub(pattern, '', textfile)  # 将符合模式的字符去除
            wordlist = jieba.lcut(textfile)  # 切割词语
            for i in range(len(wordlist) - 1, -1, -1):
                if wordlist[i] in stopwords or len(wordlist[i]) < 2:
                    del wordlist[i]
            word_counts = collections.Counter(wordlist)

        # 第四步：生成词云图
        backgroud = np.array(Image.open(self.pic_path))
        wc = WordCloud(width=1400, height=2200,
                       background_color='white',
                       mode='RGB',
                       mask=backgroud,  # 添加蒙版，生成指定形状的词云，并且词云图的颜色可从蒙版里提取
                       max_words=500,
                       stopwords=STOPWORDS,  # 内置的屏蔽词,并添加自己设置的词语
                       font_path='msyh.ttc',
                       max_font_size=150,
                       relative_scaling=0.6,  # 设置字体大小与词频的关联程度为0.4
                       random_state=50,
                       scale=2
                       ).generate_from_frequencies(word_counts)
        image_color = ImageColorGenerator(backgroud)  # 设置生成词云的颜色，如去掉这两行则字体为默认颜色
        wc.recolor(color_func=image_color)

        # plt.imshow(wc)  # 显示词云
        # plt.axis('off')  # 关闭x,y轴
        # plt.show()  # 显示
        wc.to_file('wordcloud.png')   # 保存词云图





# -*- coding: utf-8 -*-
import os
import sys
import warnings
from tqdm import tqdm
import logging

root_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), '../../../..')
dir_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), '..')
sys.path.append(root_path)

logging.basicConfig(level=logging.DEBUG)


class PDFOCR(object):
    """
    将PDF文本转换为txt或者word
    """
    def __init__(self):
        """
        Initialization.
        """
        # Set file path.
        self.data_path = os.path.join(dir_path, 'data')

    def run(self):
        """
        执行OCR转换

        :return:
        """




# -*- coding: utf-8 -*-
from PIL import Image
import sys


def fill_image(image):
    """
    对于不为正方形的图片，进行填充到正方形

    :param image:
    :return:
    """
    # 获取图片长宽
    width, height = image.size
    # 选取长和宽中较大值作为新图片的size
    new_image_length = width if width > height else height
    # 生成新图片[白底]
    new_image = Image.new(image.mode, (new_image_length, new_image_length), color='white')
    # 将之前的图粘贴在新图上，居中
    if width > height:
        new_image.paste(image, (0, int((new_image_length - height) / 2)))  # (x,y)二元组表示粘贴上图相对下图的起始位置
    else:
        new_image.paste(image, (int((new_image_length - width) / 2), 0))

    return new_image


def cut_image(image):
    """
    切成九宫图

    :param image:
    :return:
    """
    # 获取图片size
    width, height = image.size
    item_width = int(width / 3)
    box_list = []

    # 按九宫格切图
    for i in range(0, 3):
        for j in range(0, 3):
            box = (j * item_width, i * item_width, (j + 1) * item_width, (i + 1) * item_width)
            box_list.append(box)
    image_list = [image.crop(box) for box in box_list]

    return image_list

def save_images(image_name, image_list):
    """
    保存图片

    :param image_list:
    :return:
    """
    index = 1
    image_name = image_name.split('.')[0]
    for image in image_list:
        image.save(image_name + '_九宫格_' + str(index) + '.png', 'PNG')
        index += 1


def main_cut(image_name):
    """
    裁剪九宫格的主函数

    :param image_name:
    :return:
    """
    image = Image.open(image_name)
    image = fill_image(image)
    image_list = cut_image(image)
    save_images(image_name, image_list)



import setuptools

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name="naiximing",
    version="0.0.2",
    author="kexi",
    author_email="498100059@qq.com",
    description="各种有趣的工具合集.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/AxsPlayer/Tool_AI-Task",
    packages=setuptools.find_packages(),
    install_requires=['Pillow'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
